pub fn summarize(row: &SessionRow, n_events: usize) -> StringExpand description
Heuristic summary of a prior session for the resume banner.
pub fn summarize(row: &SessionRow, n_events: usize) -> StringHeuristic summary of a prior session for the resume banner.