pub fn picker_rows(picker: &SlashPicker) -> u16Expand description
Rows the picker will actually consume in the layout at the
caller’s current width. Never more than PICKER_MAX_VISIBLE;
never more than the number of matches.
pub fn picker_rows(picker: &SlashPicker) -> u16Rows the picker will actually consume in the layout at the
caller’s current width. Never more than PICKER_MAX_VISIBLE;
never more than the number of matches.